@@ -1,8 +1,8 @@
 # $Author: ddumont $
-# $Date: 2008-03-17 14:36:29 +0100 (Mon, 17 Mar 2008) $
-# $Revision: 544 $
+# $Date: 2008-05-20 13:02:22 +0200 (Tue, 20 May 2008) $
+# $Revision: 677 $
 
-#    Copyright (c) 2007 Dominique Dumont.
+#    Copyright (c) 2007-2008 Dominique Dumont.
 #
 #    This file is part of Config-Model-Curses-UI.
 #
@@ -46,7 +46,7 @@ use Exception::Class
   ) ;
 
 use vars qw($VERSION) ;
-$VERSION = sprintf "1.%04d", q$Revision: 544 $ =~ /(\d+)/;
+$VERSION = sprintf "1.%04d", q$Revision: 677 $ =~ /(\d+)/;
 
 my @help_settings = qw/-bg green -fg black -border 1 
                        -titlereverse 0
@@ -70,7 +70,7 @@ sub new {
 				    #-debug => 1
 				   );
 
-    $self->{permission} = $args{permission} || 'intermediate' ;
+    $self->{experience} = $args{experience} || 'beginner' ;
 
     my %cb_set 
       = (
@@ -95,7 +95,7 @@ sub new {
       $self->{scan} = Config::Model::ObjTreeScanner
 	-> new (
 		fallback   => 'all',
-		permission => $self->{permission},
+		experience => $self->{experience},
 		%cb_set ,
 	       ) ;
   };
@@ -466,11 +466,11 @@ sub display_node_content {
         my $help = $node->get_help($sel) ;
         $help = "no help for $sel" unless $help ;
         $helpw->text($help)  ;
-	if ($self->{permission} ne 'intermediate') {
+	if ($self->{experience} ne 'beginner') {
 	    my $p = $node
-	      -> get_element_property(property => 'permission',
+	      -> get_element_property(property => 'experience',
 				      element  => $sel) ;
-	    $permw->text("permission: $p");
+	    $permw->text("experience: $p");
 	}
 	my $type = $node->element_type($sel) ;
 	my $elt = $node->fetch_element($sel) ;
@@ -1538,7 +1538,7 @@ sub display_view_list {
 
     my $leaf_cb = ($select eq 'audit') ? $audit_cb : $std_cb ;
 
-    my @scan_args = ( permission       => $self->{permission},
+    my @scan_args = ( experience       => $self->{experience},
                       fallback         => 'all',
  		      hash_element_cb  => $hash_cb ,
 		      leaf_cb          => $leaf_cb ,
@@ -1777,7 +1777,7 @@ sub wiz_walk {
 	} ;
     }
 
-    my @wiz_args = (permission        => $self->{permission},
+    my @wiz_args = (experience        => $self->{experience},
 		    hash_element_cb   => $hash_element_cb ,
 		    %cb_hash 
 		   );
@@ -1822,7 +1822,7 @@ Config::Model::CursesUI - Curses interface to edit config data
  # create dialog
  my $dialog = Config::Model::CursesUI-> new
   (
-   permission => 'intermediate', # or 'advanced'
+   experience => 'beginner', # or 'advanced'
   ) ;
 
  # start never returns
@@ -1843,11 +1843,11 @@ The constructor accepts the following parameters:
 
 =over
 
-=item permission
+=item experience
 
-Specifies the permission level of the user (default:
-C<intermediate>). The permission can be C<master advanced
-intermediate>.
+Specifies the experience level of the user (default:
+C<beginner>). The experience can be C<master advanced
+beginner>.
 
 =item load
 
